#
# spec file for package post-build-checks
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           post-build-checks
Summary:        post checks for build after rpms have been created
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
Version:        84.87+git20231107.61af484
Release:        1.1
PreReq:         aaa_base
PreReq:         permissions
PreReq:         sed
Requires:       aaa_base-malloccheck
Requires:       gawk
URL:            https://github.com/openSUSE/post-build-checks
#
# Note: don't rebuild this manually. Instead submit your patches
# for inclusion in the git repo!
#
# git clone https://github.com/openSUSE/post-build-checks.git
# osc service dr
#
Source0:        %{name}-%{version}.tar.xz
BuildArch:      noarch

%description
some scripts to check for problems like test-installing the newly
created rpms and checking the logfile for errors.

This package will also set/change the following sysconfig variables, so
it may not be a good idea to install this to a running system:
/etc/sysconfig/security:PERMISSION_SECURITY="secure"
/etc/sysconfig/clock:TIMEZONE="UTC"

%prep
%setup -q

%build
%define _lto_cflags %{nil}
# nothing to do

%install
install -d $RPM_BUILD_ROOT/usr/lib/build/checks
install -d $RPM_BUILD_ROOT/usr/lib/build/post-mkbaselibs-checks
install -d $RPM_BUILD_ROOT/usr/lib/build/checks-data
install -d $RPM_BUILD_ROOT/usr/lib/build/helper
install -d $RPM_BUILD_ROOT/usr/lib/build/finalize-system
install -m 755 checks/* $RPM_BUILD_ROOT/usr/lib/build/checks
install -m 755 post-mkbaselibs-checks/* $RPM_BUILD_ROOT/usr/lib/build/post-mkbaselibs-checks
install -m 644 checks-data/* $RPM_BUILD_ROOT/usr/lib/build/checks-data
install -m 755 helper/* $RPM_BUILD_ROOT/usr/lib/build/helper
install -m 755 finalize-system/* $RPM_BUILD_ROOT/usr/lib/build/finalize-system
install -m 644 -D suse-buildsystem.sh  $RPM_BUILD_ROOT/etc/profile.d/suse-buildsystem.sh
install -m 644 -D suse-ignored-rpaths.conf $RPM_BUILD_ROOT/etc/suse-ignored-rpaths.conf
chmod 755 $RPM_BUILD_ROOT/usr/lib/build/checks-data/check*

%files
%license COPYING
/usr/lib/build
/etc/profile.d/suse-buildsystem.sh
/etc/suse-ignored-rpaths.conf

%changelog
* Tue Nov  7 2023 dmueller@suse.com
- Update to version 84.87+git20231107.61af484:
  * Add abuild to trusted group without using usermod
* Tue Oct 31 2023 dmueller@suse.com
- Update to version 84.87+git20231031.bfa988b:
  * Revert "Set SOURCE_DATE_EPOCH"
* Fri Oct 27 2023 dmueller@suse.com
- Update to version 84.87+git20231027.ea7097f:
  * Avoid test on unset variables
* Tue Oct 24 2023 dmueller@suse.com
- Update to version 84.87+git20231024.7161a8a:
  * Set SOURCE_DATE_EPOCH
* Wed Mar 29 2023 dmueller@suse.com
- Update to version 84.87+git20230328.de7e9df:
  * Light shell cleanups (fixes #57)
* Thu Mar  2 2023 dmueller@suse.com
- Update to version 84.87+git20230302.ff58c9e:
  * delete-x86_64-subarches: don't search in RPMS dir if not present
* Fri Jan  6 2023 dmueller@suse.com
- Update to version 84.87+git20230106.3a359c5:
  * Only delete subarch packages if matching main arch exists
* Wed Dec 21 2022 Dirk Müller <dmueller@suse.com>
- Add hook to delete x86_64 subarches
- fix version in git
* Fri Nov 25 2022 ro@suse.de
- Update to version 84.87+git20221125.a8b2d0e:
  * Add mount, umount, swapon and swapoff to ESSENTIAL_PKG_TO_KEEP
* Fri Sep 23 2022 dimstar@opensuse.org
- Update to version 84.87+git20220922.95e4f0a:
  * Follow symlinks to infer which packages to keep
  * Convert egrep/fgrep calls to grep -E/-F, respectively
  * code cleanup
  * update 50-check-kernel-build-id for compression and location of kernels
  * reduce work in installtest script
  * use predictable C locale for rpm listing
  * Speedup check-lanana
  * 50-check-kernel-build-id: handle riscv64
* Mon Mar 28 2022 meissner@suse.com
- Update to version 84.87+git20220325.f46ef3c:
  * enable -z now linking by default
* Tue Mar 22 2022 dmueller@suse.com
- Update to version 84.87+git20220322.48f07a0:
  * Remove errneous whitespaces
  * fix comparison name
* Mon Mar 21 2022 lnussel@suse.de
- Update to version 84.87+git20220321.9651edb:
  * Restore secure permissions in build environment (bsc#1159963)
  * Handle default being easy
  * Various speedups around invoking rpm
- change service file from disabled to manual
* Fri Jan 28 2022 ro@suse.de
- Update to version 84.87+git20220128.77a97b9:
  * change cross build detection logic to be more robust
  * kill useless use of cat awards
* Fri Jan 28 2022 ro@suse.de
- Update to version 84.87+git20220128.2a04ecb:
  * keep package that provides /usr/bin/sh
* Mon May 17 2021 ro@suse.de
- Update to version 84.87+git20210517.d960568:
  * support cross builds
* Thu Mar  4 2021 lnussel@suse.de
- Update to version 84.87+git20210304.df696a0:
  * final name is glibc-usrmerge-bootstrap-helper
* Mon Feb 15 2021 ro@suse.de
- Update to version 84.87+git20210215.ed75983:
  * Don't deinstall any pam_unix variant
* Mon Feb  8 2021 lnussel@suse.de
- Update to version 84.87+git20210208.d8d4154:
  * Don't remove usrmerge helper packages (boo#1029961)
* Wed Sep 16 2020 ro@suse.de
- Update to version 84.87+git20200916.d341ab0:
  * add finalize-system hacks
  * 01-add_abuild_user_to_trusted_group
  * also create abuild user if needed
  * 02-set_timezone_to_utc
  * 11-hack_uname_version_to_kernel_version
  * 98-revert-uname-hack
  * add cleanup as check script
- drop all pre/post scripts this is now all done by hooks
  inside the buildsystem, the package install scripts will
  not do any harm now and we do not depend on the install
  sequence any more (revisited boo#1159963)
* Mon Aug 24 2020 ro@suse.de
- add the abuild user to the trusted group so that
  fusermount works (boo#1159963)
* Wed Aug 19 2020 ro@suse.de
- Update to version 84.87+git20200819.5847424:
  * Revert "50-check-permissions use --level option of chkstat"
* Tue Aug 18 2020 ro@suse.de
- Update to version 84.87+git20200818.e4ffaa8:
  * 50-check-permissions use --level option of chkstat
    (boo#1159963)
* Mon Mar 23 2020 kukuk@suse.com
- Update to version 84.87+git20200323.45c6eba:
  * Don't remove find, gzip and cpio
* Thu Mar 19 2020 lnussel@suse.de
- Update to version 84.87+git20200319.57fe0e2:
  * Don't de-install the packages containing su and sh
* Thu Mar  5 2020 lnussel@suse.de
- Update to version 84.87+git20200305.61b5cdf:
  * Fix ghost logic
* Fri Jan 10 2020 lnussel@suse.de
- Update to version 84.87+git20200110.2d02f07:
  * Tweaks to make rpm-ndb build
  * Detect name of coreutils package and don't remove it
- restore correct version
* Tue Jan  7 2020 ro@suse.com
- Update to version 84.88+git20200107.dc3b3a3:
  * 99-check-remove-rpms: preserve libgomp variants
* Tue Jul 16 2019 ro@suse.com
- Update to version 84.88+git20190716.5a0e034:
  * Remove unused tests.
* Fri Jul 12 2019 Martin Liška <mliska@suse.cz>
- Disable tests as GCC checks are gone.
* Thu Jul 11 2019 ro@suse.com
- Update to version 84.88+git20190711.2b1c662:
  https://github.com/openSUSE/post-build-checks/pull/26
  * Remove GCC check output check.
* Tue Jul  2 2019 ro@suse.com
- Update to version 84.88+git20190702.429d0e0:
  * Completly don't use ghosts like files
  * Ignore ghosts
* Thu Jun 20 2019 Martin Liška <mliska@suse.cz>
- Disable LTO as some warnings are emitted late and
  disappear with usage of -c (boo#1138834).
* Mon Oct 15 2018 ro@suse.de
- Update to version 84.88+git20181015.ceb5c96:
  * Add suse-ignored-rpaths.conf (bsc#1109470)
* Thu Sep 20 2018 ro@suse.de
- Update to version 84.88+git20180920.ef3d8cb:
  * 50-check-kernel-build-id
  - add archs i686 ppc ppc64 s390 armv6l armv7l
* Thu Sep 20 2018 ro@suse.de
- Update to version 84.88+git20180920.51eb861:
  * 50-check-kernel-build-id
  - regroup checks for image and debuginfo
  - make arch list a little more robust
  - Handle i586. Also improve error handling when arch not found.
  - Change err() to return 0. Only return 1 if we successfully
    compared the id's and there was a discrepancy.
  - change file mode to 755 for 50-check-kernel-build-id to match
    all other checks
  * make all OBS tex pdf builds reproducible by exporting
    FORCE_SOURCE_DATE as 1
* Mon Sep 17 2018 ro@suse.de
- Update to version 84.88+git20180917.23b80ae:
  * check for -fstack-clash-protection instead of -fmessage-length,
    as that one will be removed from optflags
  * Add kernel-build-id consistency check
* Thu Aug  9 2018 adrian@suse.de
- Update to version 84.88+git20180809.3be1b09:
  * Warnings for core files, no errors yet
  * QT_HASH_SEED has to be 0
* Wed Apr 11 2018 ro@suse.de
- Update to version 84.87+git20180412.b38aed4:
  * Mark test as broken due to GCC 8 and fortification.
* Tue Jan 16 2018 tchvatal@suse.com
- Update to version 84.87+git20171221.9eed556:
  * Move all scripts that can run in parallel to the same run-level (50).
* Fri Nov 24 2017 ro@suse.de
- Update to version 84.87+git20171124.8f470bc:
  * export QT_HASH_SEED
  * Fix incorrect matching due to greedy regexp (Fixes: #14)
  * Also treat c++ as a valid compiler
  * check_gcc_output: drop ansi escape sequences (colors)
    before checking for warnings
* Sun Oct 22 2017 ro@suse.de
- Update to version 84.87+git20170929.5b244d1:
  * Fix performance regression in warning match regexp
* Wed Jul 12 2017 tchvatal@suse.com
- Update to version 84.87+git20170712.7ededdb:
  * Fix spacing in sequence-point warning
  * Try harder matching soname changes/tweaks (this fixes lua name change)
* Tue Apr 11 2017 lnussel@suse.de
- Update to version 84.87+git20170411.08a40e3:
  * use PYTHONHASHSEED=0
* Tue Apr 11 2017 lnussel@suse.de
- Update to version 84.87+git20170411.50017fe:
  * use fixed hash seed values for perl+python
  * Support new buffer overflow format for GCC7.
* Thu May 12 2016 lnussel@suse.de
- Update to version 13.2+git20160512.be9650e:
  * Do not remove packages that had a corresponding -mini installed
* Mon Aug 10 2015 lnussel@suse.de
- Update to version 13.2+git20150810.2703d2a:
  + Fix quoting of TOPDIR in regex pattern
  + Skip 03-check-binary-kernel-log for kernel-docs package
* Tue Mar 24 2015 lnussel@suse.de
- Update to version 13.2+git20150324.8993d63:
  + an empty main() is now allowed in C, use a different function
* Tue Oct  7 2014 dmueller@suse.com
- Update to version 13.2+git20141007.c6e35c3:
  + Fix check for skipping libgcc/libstdc++
* Tue Mar 18 2014 ro@suse.com
- also allow -MM additional to -MD to asssume were only generating deps
* Thu Feb 20 2014 ro@suse.de
- test for existence before trying to modify /etc/sysconfig/clock
* Tue Feb  4 2014 ro@suse.com
- do not remove libgcc or libstdc++ packages in install-check
* Fri Jan 31 2014 ro@suse.de
- adapt uname linking in specfile to /usr move (bnc#860600)
* Fri Jan 31 2014 ro@suse.com
- adapt uname.sh helper to 3.XX.Y kernel versioning scheme
- obs removes dashes...
- fix mktar to match service file
- do not mount and umount /proc in checks - the build script handles that
* Thu Jan  9 2014 coolo@suse.com
- the switching to services undid the mounting fix - without me
  noticing. Now really pushed to the right git and redid tar
* Tue Jan  7 2014 coolo@suse.com
- switch to _service file to avoid silent tar updates
* Tue Jan  7 2014 coolo@suse.com
- remove mounting and unmounting of /proc - build handles it
* Mon Dec  9 2013 ro@suse.com
- merge rest of quoting fixes from schwab
* Mon Dec  9 2013 ro@suse.com
- fix quoting in libtool deps check
* Fri Oct 11 2013 coolo@suse.com
- make use of the same findfileconflicts as the one repo-checker uses
- switched repo location to github
* Mon Dec 10 2012 coolo@suse.com
- buildrequire malloc check
* Wed Nov 14 2012 ro@suse.com
- Remove timestamp prefix in check_gcc_output (thanks to schwab)
* Sat Oct 27 2012 coolo@suse.com
- the scripts call awk, so we need to require it
* Thu Oct  4 2012 dmueller@suse.com
- merge /proc mount/umounting patch from AJ
- add _service file to easily recreate the tarball from git
* Sun Sep 23 2012 coolo@suse.com
- change the permissions check to use chkstat directly,
  possibly this check outdated itself though
* Mon Sep 17 2012 coolo@suse.com
- with rpm 4.10, two packages packaging the same directory with
  different owners is a bug - so catch it early
* Tue Jun 26 2012 lnussel@suse.de
- use mkpackage from aaa_base, more advanced
- merge package patches into git
* Tue Jun 26 2012 saschpe@suse.de
- Update reserved init script names from LANANA.
  The current authoritative list is currently found here:
  http://stewbenedict.org/lsb/lanana/lsbreg/init/init.txt
* Mon Jun  4 2012 coolo@suse.com
- ld.so is basically empty nowadays, so put together a config file
  just to ignore rpaths
* Mon May 28 2012 coolo@suse.com
- strim white space in check_gcc_output - this reduces the time
  to check an openSUSE-images log file (38M mostly whitespace due
  to zypper output) from several hours to some seconds
* Tue Dec 20 2011 werner@suse.de
- ignore empty rpm as in 09-check-packaged-twice as those will be
  detected by rpmlint rules with a clear message
* Wed Dec  7 2011 coolo@suse.com
- ignore debuginfo and debugsource packages for packaged-twice
* Thu Dec  1 2011 coolo@suse.com
- fix usage of perl's index()
* Mon Nov 28 2011 coolo@suse.com
- ignore files that are %%ghost in both packages
* Fri Nov 25 2011 coolo@suse.com
- make "packaged twice" fatal if packages do not conflict
* Thu Oct 20 2011 ro@suse.com
- use /.build.packages instead of /usr/src/packages if it exists
* Fri Jul 22 2011 lnussel@suse.de
- Fix filelist check for new rpm
* Wed Jun 22 2011 dmueller@suse.de
- fix strict-aliasing compiler check with gcc 4.6
* Tue Jun 21 2011 dmueller@suse.de
- re-enable fatal checks in 04-check-filelist as the deadline has
  passed
* Fri Mar 25 2011 ro@suse.de
- drop sync workaround again
* Sun Mar 20 2011 ro@suse.de
- add helper/sync.sh to disable sync inside build environment
* Tue Dec  7 2010 lnussel@suse.de
- re-enable fatal checks in 04-check-filelist as the deadline has
  passed
* Tue Nov 30 2010 lnussel@suse.de
- maintain sources in git
* Mon Nov  8 2010 lnussel@suse.de
- disarm 04-check-filelist for now. Too many failures.
* Thu Nov  4 2010 lnussel@suse.de
- revive 04-check-filelist part that checks for unpackaged
  directory. Not possible to implement with rpmlint atm.
* Mon May 31 2010 sbrabec@suse.cz
- Removed 11-check-pkgconfig-deps as it is now part of rpm
  (bnc#610280).
* Thu May  6 2010 lnussel@suse.de
- finally remove 04-check-filelist as it's obsoleted by
  CheckFilelist.py in rpmlint
* Wed Apr  7 2010 ro@suse.de
- remove debuginfo packages for nosrc rpms unless
  package is either kernel or java or texlive-bin or glibc
  or removal is disabled in specfile by adding a line
  [#]KEEP NOSOURCE DEBUGINFO
  to the specfile (bnc#572695)
* Tue Feb 23 2010 ro@suse.de
- check gcc warnings: wording for non-void return has changed
* Fri Feb 19 2010 mls@suse.de
- allow /usr/src/parrot in parrot-devel
* Sat Feb  6 2010 detlef@links2linux.de
- add umount patch: Umount $BUILD_ROOT/proc after finished job
* Mon Dec  7 2009 mmarek@suse.cz
- do not mess with sysconfig files when installed in a live system
  (no more missed appointments...).
* Thu Nov  5 2009 meissner@suse.de
- move strcasecmp and strlcpy to "implict warning" as we have
  no specific fortify checking for those.
* Tue Oct 20 2009 meissner@suse.de
- merge debuginfo patch into tarball
- check for "implicit declaration of function 'xxxx'" with a fixed
  list of standard library xxxx which will change behaviour when having
  correct declaration.
* Mon Aug 10 2009 ro@suse.de
- allow /selinux in filelist check
* Thu Jul 30 2009 rguenther@suse.de
- simplify and fix empty debuginfo/source deletion
* Mon Jul 27 2009 rguenther@suse.de
- also remove empty debugsource packages
* Wed Jun 24 2009 coolo@novell.com
- reenable -as-needed now that most of the fallout is fixed
* Sat Jun 13 2009 coolo@novell.com
- take out AS_NEEDED for now to see a before-after comparision
* Wed Jun 10 2009 coolo@novell.com
- add a profile.d script that sets -as-needed when in build environment
* Tue May 26 2009 ro@suse.de
- fix last change
* Fri May 22 2009 ro@suse.de
- more ugly tweaks to uname hack
* Mon Feb 23 2009 ro@suse.de
- cleanup uname hack in preun (bnc#476885)
* Fri Feb 20 2009 coolo@suse.de
- don't make the sequence point gcc warnings fatal, but let security
  team review them case by case
* Tue Oct 28 2008 lnussel@suse.de
- remove suid check. replaced by rpmlint script
* Mon Oct 27 2008 meissner@suse.de
- added warning checks for: array subscript over/underflow,
  void return not expected warnings. bnc#240922,bnc#439283
* Thu Oct 23 2008 lnussel@suse.de
- suid check: tetex -> texlive
* Wed Oct 22 2008 lnussel@suse.de
- don't fail for setuid/setgid directories (bnc#437721)
- some cleanups
* Wed Oct 22 2008 lnussel@suse.de
- failed setuid check is fatal (bnc#431592)
* Tue Oct 14 2008 dmueller@suse.de
- remove extra whitespace in warning output that confuses people
* Mon Oct 13 2008 ro@suse.de
- allow /opt/IBMJava2-*
* Tue Oct  7 2008 meissner@suse.de
- testsuite for check_gcc_output. marked the currently non
  working tests as "BROKEN.C" (not built).
- fixed implicit fortify function check to work with newer gccs.
* Mon Oct  6 2008 meissner@suse.de
- added checks for newer glibcs destination buffer overflow
  warning.
* Tue Sep 30 2008 ro@suse.de
- make uname.sh more robust
* Tue Sep 23 2008 dmueller@suse.de
- remove uses-function-address debug statement, confuses more
  people than it helps
* Mon Sep 15 2008 ro@suse.de
- allow /opt/IBMJava2-142
* Fri Sep  5 2008 ro@suse.de
- next hack for uname.sh: if /.kernelversion does not exist
  use a readlink on /usr/src/linux to find out
  and then get the flavor by the same hack as kernel-source
* Thu Sep  4 2008 ro@suse.de
- added COPYING file
* Wed Sep  3 2008 ro@suse.de
- try not to remove library packages during initial build
  (when updating soname bnc#421981)
* Wed Aug 20 2008 ro@suse.de
- allow /var/crash for crash-dumps (FHS-2.3)
- allow /branding (installation-images)
* Fri Aug 15 2008 ro@suse.de
- make sure LOGFILE is set for gcc warning check
* Mon Aug 11 2008 ro@suse.de
- eliminate use of BUILD_IS_RUNNING
* Mon Aug 11 2008 ro@suse.de
- eliminate use of BUILD_BASENAME and package_name
* Sun Aug 10 2008 ro@suse.de
- add uname hack: let "uname -r" return the version of the
  installed kernel-sources, not the one of the running kernel
* Fri Aug  8 2008 ro@suse.de
- some sysconfig hacks:
  sysconfig/security:PERMISSION_SECURITY to secure
  sysconfig/clock:TIMEZONE to UTC
- add PreReq "aaa_base permissions sed" to make this work
* Mon Aug  4 2008 ro@suse.de
- change debuginfo dependency checker:
  only fail on dependencies not referring to debuginfo packages
* Mon Jul 28 2008 ro@suse.de
- fail if a debuginfo or debugsource package has
  an unresolvable dependency
* Tue Jul 15 2008 ro@suse.de
- replace last cleanup_and_exit by exit
- make sure proc is mounted before uninstalling rpms
- export YAST_IS_RUNNING during all install/uninstall tests
* Mon Jul 14 2008 ro@suse.de
- added 00-install and 99-remove as next part of main build script
* Mon Jul 14 2008 ro@suse.de
- created package
